@@ -1,19 +1,8 @@
 # pylint: disable=missing-module-docstring,missing-function-docstring,unused-variable,too-many-locals,too-many-statements
 import pytest  # pylint: disable=unused-import
 
-from lm_scorer.models.auto import AutoLMScorer as AutoLMScorer
-from lm_scorer.models.gpt2 import GPT2LMScorer as GPT2LMScorer
-
-
-def assert_score_of_sentence_pairs(scorer, sentence_pairs):
-    errors = []
-    for i, sentence_pair in enumerate(sentence_pairs):
-        correct_sentence, wrong_sentence = sentence_pair
-        correct_score = scorer.score(correct_sentence)
-        wrong_score = scorer.score(wrong_sentence)
-        if not correct_score > wrong_score:
-            errors.append(i)
-    assert errors == []
+from lm_scorer.models.auto import AutoLMScorer
+from lm_scorer.models.gpt2 import GPT2LMScorer
 
 
 def describe_init():
